@@ -1139,6 +1139,7 @@ static void nntpactive( time_t update ) {
 			    error++;
 			} while ( l && *l && *l != '.' );
 			if ( error > 1 ) {
+			    current_server->descriptions = 0;
 			    syslog( LOG_NOTICE, "warning: %s does not process "
 				   "LIST NEWSGROUPS %s correctly: use nodesc\n",
 				   current_server->name, helpptr->string );
@@ -1253,6 +1254,7 @@ int postarticles( void ) {
 
     while ( (de=readdir( d )) != NULL ) {
 	haveid = 0;
+	f = NULL;
 	if(!strcmp(".", de->d_name) || !strcmp("..", de->d_name)) {
 	     continue;
 	}
@@ -1330,11 +1332,14 @@ int postarticles( void ) {
 	    fclose( f );
 	    haveid = 0;
 	} else if ( haveid ) {
+	    fclose( f );
 	    syslog( LOG_INFO, "Message-ID of %s already in use upstream -- "
 			"article discarded\n", de->d_name );
 	    if ( verbose > 2 )
 		printf( "%s already available upstream\n", de->d_name );
 	    unlink( de->d_name ); 
+	} else if ( f ) {
+	    fclose( f );
 	}
     }
     closedir( d );
