@@ -687,6 +687,7 @@ char *getaline(FILE *f) {
     static size_t size;     /* size of buffer */
     size_t len;             /* # of chars stored into buf before '\0' */
     char * p;
+    int i;
 
     len = 0;
     if (!size)
@@ -694,12 +695,21 @@ char *getaline(FILE *f) {
     if (!buf)
 	buf = critmalloc( size, "reading line" );
 
-    while ((p=fgets(buf+len, size-len, f)) != NULL) {
+    while ((p=fgets(buf+len, size-len, f))) {
+	/* replace NUL bytes (which shouldn't be there anyway)
+	 * with spaces
+	 */
+	i = size - len;
+	while ( *p != '\n' && --i > 0 ) {
+	    if ( *p == '\0' )
+		*p = ' ';
+	    p++;
+	}
 	len += strlen(buf+len);
-        if (len > 0 && ( buf[len-1] == '\n' || len < size-1 ) )
-	    break;          /* the whole line has been read */
+	if ( buf[len-1] == '\n' )
+	    break;		/* the whole line has been read */
 
-	size += size+100;
+	size += size;		/* exponential growth of buffer */
 	buf = critrealloc(buf, size, "reading line" );
     }
 
